@@ -1,5 +1,5 @@
 package Kwiki::DB;
-use Kwiki::Base -Base;
+use Kwiki::Plugin -Base;
 our $VERSION = '0.01';
 
 const id => 'db';
